@@ -14,17 +14,13 @@
 #    under the License.
 #
 
-import logging
-
 from neutronclient.neutron import v2_0 as cmd_base
-from neutronclient.openstack.common.gettextutils import _
 
 
 class ListExt(cmd_base.ListCommand):
     """List all extensions."""
 
     resource = 'extension'
-    log = logging.getLogger(__name__ + '.ListExt')
     list_columns = ['alias', 'name']
 
 
@@ -32,13 +28,4 @@ class ShowExt(cmd_base.ShowCommand):
     """Show information of a given resource."""
 
     resource = "extension"
-    log = logging.getLogger(__name__ + '.ShowExt')
     allow_names = False
-
-    def get_parser(self, prog_name):
-        parser = super(cmd_base.ShowCommand, self).get_parser(prog_name)
-        cmd_base.add_show_list_common_argument(parser)
-        parser.add_argument(
-            'id', metavar='EXT-ALIAS',
-            help=_('The extension alias.'))
-        return parser
